pub struct BenchmarkingJobOpts {
pub insert_benchmarking_job_opts: InsertBenchmarkingJobOpts,
pub commit_id: GitHash,
}Fields
insert_benchmarking_job_opts: InsertBenchmarkingJobOptsOptional overrides for what values might come from elsewhere
commit_id: GitHashImplementations
Sourceimpl BenchmarkingJobOpts
impl BenchmarkingJobOpts
Sourcepub fn complete_jobs(
&self,
job_template_list: &[JobTemplate],
) -> Vec<BenchmarkingJob>
pub fn complete_jobs( &self, job_template_list: &[JobTemplate], ) -> Vec<BenchmarkingJob>
Make one job per job template, filling the missing values
(currently just priority and initial_boost) and all other
values from the job template.